Search.setIndex({envversion:42,terms:{all:1,execut:1,from:[1,2],follow:[1,2,3],disk:1,find:1,bunch:1,absolut:1,compendex:1,system:[1,2],easi:2,how:2,graph:1,except:1,should:1,better:[1,3],platform:2,window:1,other:1,local:1,introduc:3,sourc:1,hit:1,string:1,format:1,overal:3,howto:2,initi:1,util:[2,3],"import":1,brows:1,requir:1,choic:1,name:1,specif:2,anyth:1,complic:1,possibl:2,list:1,server:1,separ:1,easili:2,sane:1,contain:1,small:3,readthedoc:1,where:1,manag:2,mean:1,enjoy:3,www:2,set:2,old:[1,2],dump:2,replac:1,hard:1,some:[1,3],second:1,connect:1,todo:1,out:1,even:1,index:0,still:1,goe:2,someth:2,abl:2,"while":1,yet:1,content:0,version:[1,3],rel:1,"new":[],gexf:1,experi:3,ever:2,localhost:1,refer:[2,3],run:1,navig:1,web:1,gener:1,style:3,address:1,releas:[1,3],path:[1,2],addit:[2,3],search:0,central:1,befor:1,anymor:1,moment:1,bak:2,thing:1,place:1,countri:1,chang:3,whole:2,think:1,first:1,major:1,backup:2,modul:0,prefer:1,dataset:1,deprec:1,done:1,org:[1,2],instal:[1,3],txt:1,your:1,merg:3,differ:1,institut:3,describ:[1,2,3],scopu:1,interact:1,add:3,next:1,start:1,ibiblio:2,interfac:3,termin:1,minor:3,more:[1,3],tool:[1,2,3],relat:3,convert:1,than:1,"case":[1,2],init:1,restor:2,provid:[2,3],access:1,see:3,record:[1,3],below:[1,3],can:[1,2,3],about:3,root:1,browser:1,control:1,sqlite:[],have:1,creat:2,give:1,ani:1,strongli:2,pip:[1,3],dedupl:3,good:1,file:1,need:2,work:[1,2,3],alwai:1,built:2,want:1,author:[1,3],suggest:2,when:[1,2],cross:2,same:3,write:[1,3],"default":1,html:2,futur:1,which:3,sqlite3:2,pagin:3,you:[1,2,3],csv:1,http:[1,2],thi:[1,3],geoloc:3,wrong:2,user:3,wherev:1,data:[2,3],keep:1,task:1,faster:3,directori:1,entri:3,page:[0,1,2],destruct:2,doe:[1,2],issu:[1,2,3],inform:3,command:[1,2,3],allow:1,time:[1,3],entiti:3,element:2,order:3,latest:[1,3]},objtypes:{},objnames:{},filenames:["index","news/version-0.6","backup","news/version-0.6.1"],titles:["Welcome to IRCO&#8217;s documentation!","News for IRCO 0.6","Backing up the database","News for IRCO 0.6.1"],objects:{},titleterms:{sqlite:2,irco:[0,1,3],welcom:0,databas:[1,2],upgrad:[1,3],indic:0,back:2,step:3,explor:[1,3],tabl:0,"new":[0,1,3],next:3,document:[0,1],updat:3}})